ParseTypeUriError

Enum ParseTypeUriError 

pub enum ParseTypeUriError {
    Scheme(String),
    Shape(String),
    Slug(String),
    ReservedSlug(String),
    Version(String),
    Fragment(String),
}
Reasons a string fails to parse as a TypeUri.

Variants



Scheme(String)

URI scheme is not https or http.



Shape(String)

The path is missing the /spec/<slug>/<version> shape.



Slug(String)

Slug fails the 6.1 grammar.



ReservedSlug(String)

Slug is in the trust-task reserved namespace and is not one of the framework-defined allowed slugs.



Version(String)

Version segment is not <MAJOR>.<MINOR>.



Fragment(String)

Fragment is set but is neither request nor response.