#[non_exhaustive]pub struct RejectedKey {
pub key: RejectedKeyKey,
pub reason: RejectedKeyReason,
}Available on crate feature
config only.Expand description
A key a patch declined to apply, with the reason.
JSON schema
{
"title": "RejectedKey",
"description": "A key a patch declined to apply, with the reason.",
"type": "object",
"required": [
"key",
"reason"
],
"properties": {
"key": {
"type": "string",
"minLength": 1
},
"reason": {
"description": "Why the key was rejected — unknown key, wrong type, out-of-range, allowlist mismatch, etc.",
"type": "string",
"maxLength": 1024,
"minLength": 1
}
},
"additionalProperties": false,
"$anchor": "rejectedKey"
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.key: RejectedKeyKeyreason: RejectedKeyReasonWhy the key was rejected — unknown key, wrong type, out-of-range, allowlist mismatch, etc.
Implementations
Sourceimpl RejectedKey
impl RejectedKey
pub fn builder() -> RejectedKey