#[non_exhaustive]pub struct PolicyModule {
pub applies_to: Option<Vec<String>>,
pub created_at: DateTime<Utc>,
pub description: Option<PolicyModuleDescription>,
pub enabled: bool,
pub ext: Option<Ext>,
pub id: PolicyModuleId,
pub module: PolicyModuleModule,
pub name: PolicyModuleName,
pub priority: Option<i64>,
pub updated_at: DateTime<Utc>,
pub version: u64,
}Available on crate feature
policy only.Expand description
PolicyModule
JSON schema
{
"title": "PolicyModule",
"type": "object",
"required": [
"createdAt",
"id",
"module",
"name",
"updatedAt",
"version"
],
"properties": {
"appliesTo": {
"description": "List of trust contexts this policy applies to. Empty array = applies to all contexts (the default policy).",
"type": "array",
"items": {
"type": "string"
},
"uniqueItems": true
},
"createdAt": {
"type": "string",
"format": "date-time"
},
"description": {
"type": "string",
"maxLength": 1024
},
"enabled": {
"default": true,
"type": "boolean"
},
"ext": {
"$ref": "#/definitions/Ext"
},
"id": {
"type": "string",
"minLength": 1
},
"module": {
"description": "Rego source code. The maintainer's evaluator entry point is the package's `decision` rule, returning a PolicyDecision.",
"type": "string",
"minLength": 1
},
"name": {
"description": "Human-readable name (e.g. \"default vault policy\", \"bank-site step-up\").",
"type": "string",
"maxLength": 128,
"minLength": 1
},
"priority": {
"description": "When multiple policies match a request, evaluation order is by priority descending. The first to return a non-`null` decision wins.",
"type": "integer",
"maximum": 1000.0,
"minimum": 0.0
},
"updatedAt": {
"type": "string",
"format": "date-time"
},
"version": {
"type": "integer",
"minimum": 0.0
}
},
"additionalProperties": false
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.applies_to: Option<Vec<String>>List of trust contexts this policy applies to. Empty array = applies to all contexts (the default policy).
created_at: DateTime<Utc>description: Option<PolicyModuleDescription>enabled: boolext: Option<Ext>id: PolicyModuleIdmodule: PolicyModuleModuleRego source code. The maintainer’s evaluator entry point is the package’s decision rule, returning a PolicyDecision.
name: PolicyModuleNameHuman-readable name (e.g. “default vault policy”, “bank-site step-up”).
priority: Option<i64>When multiple policies match a request, evaluation order is by priority descending. The first to return a non-null decision wins.
updated_at: DateTime<Utc>version: u64Implementations
Sourceimpl PolicyModule
impl PolicyModule
pub fn builder() -> PolicyModule